<?php

require_once(EZFAQPATH . "include/config.php");
require_once(EZFAQPATH . "include/admin_panel.php");

if (!class_exists("EZFaq")) {
    class EZFaq {
        var $ezfaq_admin_panel = null;
        var $ezfaq_config      = null;
        var $ezfaq_buttons     = null;

        //constructor
        function EZFaq() {}

        function admin_panel() {
            if( is_null($this->ezfaq_admin_panel) ) {
                $this->ezfaq_admin_panel = new EZFAQAdminPanel( $this->config() );
            }

            return $this->ezfaq_admin_panel;
        }

        function config() {
            if( is_null($this->ezfaq_config) ) {
                $this->ezfaq_config = new EZFAQConfig();
            }

            return $this->ezfaq_config;
        }

        function buttons() {
            if( is_null($this->ezfaq_buttons) ) {
                $this->ezfaq_buttons = new EZFAQButtons( $this->config() );
            }

            return $this->ezfaq_buttons;
        }

        function add_headers() {
            $this->add_css_headers();
        }

        function add_css_headers() {
           $config = $this->config();
           if( $config->get( 'ezfaq_toc_container_css') ) {
               echo "<style type='text/css'>\n";
               echo "#ezfaq-toc ul { \n";
               echo $config->get( 'ezfaq_toc_container_css');
               echo " \n } \n ";
               echo "</style>\n";
           }

           if( $config->get( 'ezfaq_toc_item_css') ) {
               echo "<style type='text/css'>\n";
               echo "#ezfaq-toc li { \n";
               echo $config->get( 'ezfaq_toc_item_css');
               echo "\n} \n";
               echo "</style>\n";
           }

           if( $config->get( 'ezfaq_question_css') ) {
               echo "<style type='text/css'>\n";
               echo "p.ez-question { \n";
               echo $config->get( 'ezfaq_question_css');
               echo " \n} \n";
               echo "</style>\n";
           }
        }

        function create_admin_panel() {
            if (function_exists('add_options_page')) {
                add_options_page( 'EZFaq', 'EZFaq', 9,
                                  basename(__FILE__),
                                  array($this->admin_panel(), 'print_admin_panel') );
            }
        }

        function add_tinymce_buttons() {
            if( $this->buttons() )
                $this->ezfaq_buttons->init();
        }



        function filter( $content = '' ) {
            $offset = 0;
            $i = 0;
            $pattern = "/<!--\s*EZFaq-TOC\s*-->/i";
            $toc     = $this->generate_toc( $content );
            $content = preg_replace( $pattern, $toc, $content );

            $pattern = "/(<\s*[pP][^>]*ez-question[^>]*>)/";
            $matches = preg_split( $pattern, $content, -1, PREG_SPLIT_DELIM_CAPTURE );

            $content = "";
            foreach ($matches as $val) {
                if( preg_match( $pattern, $val ) ) {
                    $val = preg_replace( "/>/", "><a name='ezfaq_$i' ></a>", $val, 1 );
                    $i++;
                }
                $content .= $val;
            }

            return $content;
        }


        function generate_toc( $content = '' ) {
            $i = 0;
            $result = "";
            preg_match_all("/(<\s*([pP])[^>]*>)(.*)(<\/\\2>)/", $content, $matches, PREG_SET_ORDER);

            foreach ($matches as $val) {
                if( preg_match('/ez-question/', $val[1]) ) {
                    $result .= "<li id='ezfaq-toc'><a href='#ezfaq_$i'>$val[3]</a></li>\n";
                    $i++;
                }
            }

            if( $result )
                $result = "<div id='ezfaq-toc'><UL id='ezfaq-toc'>\n$result</UL></div>\n";

            return $result;
        }
    }

    function ezfaq_the_content($more_link_text = '(more...)', $stripteaser = 0, $more_file = '') {
        
        $content = get_the_content($more_link_text, $stripteaser, $more_file);
        $content = apply_filters('the_content', $content);
        $content = str_replace(']]>', ']]&gt;', $content);

        if( ! $ezfaq ) 
            $ezfaq = new EZFaq();

        $config = $ezfaq->config();
        
        if( $config->get( "ezfaq_enable_filter" ) ) 
            echo $content;
        else 
            echo $ezfaq->filter($content);
    }
}


?>
